==> haskell-cpphs-1.19.3-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cpphs/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.19.3
id: cpphs-1.19.3-3bd8e8b07be299ea6c4856a14885be3e
key: cpphs_I02A1RR7RCZ6w2Apsnbhlq
license: LGPL
copyright: 2004-2015, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.19.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.19.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/cpphs-1.19.3
hs-libraries: HScpphs-1.19.3-I02A1RR7RCZ6w2Apsnbhlq
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    polyparse-1.11-83459d6d9df65afea2e279cf0b0fab90
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cpphs-1.19.3-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cpphs/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.19.3
id: cpphs-1.19.3-8cb6c3761dbbd3c20e10f28974c8d246
key: cpphs_BDvNj43Ytlf6FLaXjoKVEk
license: LGPL
copyright: 2004-2015, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.19.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.19.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/cpphs-1.19.3
hs-libraries: HScpphs-1.19.3-BDvNj43Ytlf6FLaXjoKVEk
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    polyparse-1.11-32e1e4b83edd269be9945c81b189424b
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
